@@ -16,6 +16,8 @@ from pathlib import Path
 
 my_fs = open_fs("/")
 
+log = logging.getLogger("basic-logger")
+
 
 class BasePipeline:
     def __init__(self) -> None:
@@ -24,7 +26,7 @@ class BasePipeline:
     def add_bag_info(self, path, dest):
         """
         The "bag-info.txt" file is a tag file that contains metadata elements
-        describing the bag and the payload.  The metadata elements contained
+        describing the bag and the payload. The metadata elements contained
         in the "bag-info.txt" file are intended primarily for human use.
         """
 
@@ -36,9 +38,9 @@ class BasePipeline:
         size = sum(f.stat().st_size for f in payload_path.glob("**/*") if f.is_file())
 
         baginfo = (
-            f"Bag-Software-Agent: bagit-create {__version__} <https://github.com/cerndigitalmemory/bagit-create>\n"
-            f"Bagging-Date: {d}\n"
-            f"Payload-Oxum: {size}.{file_count}\n"
+            f"Bag-Software-Agent: bagit-create {__version__}"
+            " <https://github.com/cerndigitalmemory/bagit-create>\nBagging-Date:"
+            f" {d}\nPayload-Oxum: {size}.{file_count}\n"
         )
         self.write_file(baginfo, dest)
 
@@ -52,7 +54,7 @@ class BasePipeline:
         try:
             my_fs.copy(src, dest)
         except (FileNotFoundError, fs.errors.ResourceNotFound):
-            logging.debug(f"  Path '{src}' not found. Skipping file. ")
+            log.debug(f"  Path '{src}' not found. Skipping file. ")
             return False
 
     def adler32sum(self, filepath):
@@ -86,7 +88,7 @@ class BasePipeline:
         return None
 
     def delete_folder(self, path):
-        logging.info(f"Deleted {path}")
+        log.info(f"Deleted {path}")
         shutil.rmtree(path)
 
     def write_file(self, content, dest):
@@ -96,8 +98,8 @@ class BasePipeline:
             open(f"{dest}", "w").write(json.dumps(content, indent=4))
         else:
             open(f"{dest}", "w").write(content)
-        logging.info(f"Wrote {os.path.basename(dest)}")
-        logging.debug(f"({dest})")
+        log.info(f"Wrote {os.path.basename(dest)}")
+        log.debug(f"({dest})")
 
     def download_file(self, sourcefile, dest):
         r = requests.get(sourcefile["url"])
@@ -110,9 +112,7 @@ class BasePipeline:
         """
         Creates "bagit.txt", the Bag Declaration file (BagIt specification)
         """
-        bagittxt = (
-            f"BagIt-Version: {version}\n" f"Tag-File-Character-Encoding: {encoding}\n"
-        )
+        bagittxt = f"BagIt-Version: {version}\nTag-File-Character-Encoding: {encoding}\n"
         self.write_file(bagittxt, dest)
         return bagittxt
 
@@ -128,6 +128,7 @@ class BasePipeline:
             computedhash = self.adler32sum(filename)
         else:
             computedhash = my_fs.hash(filename, alg)
+
         return computedhash
 
     def generate_manifest(self, files, algorithm, basepath):
@@ -156,18 +157,19 @@ class BasePipeline:
                 if alg == algorithm:
                     checksum = matched_checksum
                 elif file["downloaded"]:
-                    logging.info(
-                        f"Checksum {alg} found for {file['filename']} \
-                        but {algorithm} was requested."
+                    log.info(
+                        f"Checksum {alg} found for {file['filename']}                   "
+                        f"      but {algorithm} was requested."
                     )
-                    logging.debug(f"Computing {algorithm} of {file['filename']}")
+                    log.debug(f"Computing {algorithm} of {file['filename']}")
                     checksum = self.compute_hash(f"{path}/{file['filename']}", algorithm)
 
             elif file["downloaded"]:
-                logging.debug(f"No checksum available for {file['filename']}")
-                logging.debug(f"Computing {algorithm} of {file['filename']}")
+                log.debug(f"No checksum available for {file['filename']}")
+                log.debug(f"Computing {algorithm} of {file['filename']}")
                 checksum = self.compute_hash(f"{path}", algorithm)
             else:
+                # Here may needs additional checks
                 pass
             line = f"{checksum} {file['localpath']}\n"
             contents += line
@@ -210,29 +212,25 @@ class BasePipeline:
         #  e.g. "bagitexport::cds::42"
         base_name = f"bagitexport{delimiter_str}{source}{delimiter_str}{recid}"
         base_path = f"{path}/{base_name}"
-        name = base_name
 
         os.mkdir(base_path)
+
         # Create data/ subfolder (bagit payload)
         os.mkdir(f"{base_path}/data")
         os.mkdir(f"{base_path}/data/meta")
         os.mkdir(f"{base_path}/data/content")
 
-        # Create temporary folder to download the resource content
-        temp_path = f"{path}/temp_{source}_{recid}"
-        temp_relpath = f"temp_{source}_{recid}"
-        os.mkdir(temp_path)
-
         self.base_path = base_path
 
-        logging.debug(f"Bag folder: {base_name}")
-        return base_path, temp_path, name
+        log.debug(f"Bag folder: {base_name}")
+
+        return base_path, base_name
 
     def prepare_AIC(self, base_path, recid, timestamp=0, delimiter_str="::"):
-        logging.info("Creating AIC..")
+        log.info("Creating AIC..")
         # Set timestamp to now if 0 is passed
         if timestamp == 0:
-            logging.debug("No timestamp provided. Using 'now'")
+            log.debug("No timestamp provided. Using 'now'")
             timestamp = int(time.time())
         aic_name = f"{recid}{delimiter_str}{str(timestamp)}"
         aic_path = f"{base_path}/data/{aic_name}"
@@ -251,35 +249,39 @@ class BasePipeline:
                 try:
                     os.mkdir(aiufoldername)
                 except:
-                    logging.warning(
-                        "Trying to create an already existing AIU. Duplicate files or colliding checksums?"
+                    log.warning(
+                        "Trying to create an already existing AIU. Duplicate files or"
+                        " colliding checksums?"
                     )
                 files[idx][
                     "localpath"
                 ] = f"data/{recid}{delimiter_str}{filehash}/{file['filename']}"
+                try:
+                    my_fs.copy(
+                        f"{temp_relpath}/{file['filename']}",
+                        f"{base_path}/data/{recid}{delimiter_str}{filehash}/{file['filename']}",
+                    )
+                except:
+                    log.warning(f"{temp_relpath}/{file['filename']} already exists")
 
-                my_fs.copy(
-                    f"{temp_relpath}/{file['filename']}",
-                    f"{base_path}/data/{recid}{delimiter_str}{filehash}/{file['filename']}",
-                )
             if file["downloaded"] == False and file["metadata"] == False:
                 if "checksum" in file:
                     p = re.compile(r"([A-z0-9]*):([A-z0-9]*)")
                     m = p.match(file["checksum"])
                     alg = m.groups()[0].lower()
                     matched_checksum = m.groups()[1]
-
                     files[idx][
                         "localpath"
                     ] = f"data/{recid}{delimiter_str}{matched_checksum}/{file['filename']}"
                 else:
-                    logging.error(
-                        "File was not downloaded and there's not checksum available from metadata."
+                    log.error(
+                        "File was not downloaded and there's not checksum available from"
+                        " metadata."
                     )
 
         return files
 
-    def create_bic_meta(self, files, audit, metadata_filename, metadata_url, base_path):
+    def create_sip_meta(self, files, audit, timestamp, base_path, metadata_url=None):
         bic_meta = {
             "created_by": f"bagit-create {__version__}",
             "audit": audit,
@@ -287,11 +289,21 @@ class BasePipeline:
             "recid": audit[0]["param"]["recid"],
             "metadataFile_upstream": metadata_url,
             "contentFiles": files,
+            "sip_creation_timestamp": timestamp,
         }
 
+        bic_log_file_entry = {
+            "filename": "bagitcreate.log",
+            "path": "bagitcreate.log",
+            "metadata": False,
+            "downloaded": True,
+            "localpath": f"data/meta/bagitcreate.log",
+        }
+
+        files.append(bic_log_file_entry)
+
         self.write_file(
-            json.dumps(bic_meta, indent=4),
-            f"{base_path}/data/meta/sip.json",
+            json.dumps(bic_meta, indent=4), f"{base_path}/data/meta/sip.json"
         )
 
         bic_meta_file_entry = {
@@ -300,14 +312,13 @@ class BasePipeline:
             "metadata": False,
             "downloaded": True,
             "localpath": f"data/meta/sip.json",
-            "localsavepath": f"{base_path}/data/meta",
         }
-        files.append(bic_meta_file_entry)
 
+        files.append(bic_meta_file_entry)
         return files
 
     def verify_bag(self, path):
-        logging.info(f"Validating created Bag {path} ..")
+        log.info(f"\n--\nValidating created Bag {path} ..")
         bag = bagit.Bag(path)
         valid = False
         try:
@@ -315,21 +326,20 @@ class BasePipeline:
         except bagit.BagValidationError as err:
             print(f"Bag validation failed: {err}")
         if valid:
-            logging.info(f"Bag successfully validated")
+            log.info(f"Bag successfully validated")
+        log.info("--\n")
         return valid
-    
-    def move_folders(self, base_path, name, target):
-        logging.info(f"Moving files to {target} ..")
 
-        #Check if destination folder exists
+    def move_folders(self, base_path, name, target):
+        log.info(f"Moving files to {target} ..")
+
+        # Check if destination folder exists
         if not os.path.isdir(target):
             os.mkdir(target)
-        
-        #make a new folder at the target folder with the original name
+
+        # make a new folder at the target folder with the original name
         new_path = f"{target}/{name}"
         os.mkdir(new_path)
 
-        #move folder to the target location
+        # move folder to the target location
         fs.move.move_fs(base_path, new_path)
-
-
