@@ -6,10 +6,13 @@ import ntpath
 from .. import cds
 import re
 
+log = logging.getLogger("basic-logger")
+
 
 class InvenioV1Pipeline(base.BasePipeline):
     def __init__(self, base_url):
-        logging.info(f"Invenio v1 pipeline initialised.\nBase URL: {base_url}")
+
+        log.info(f"Invenio v1 pipeline initialised.\nBase URL: {base_url}")
         self.base_url = base_url
 
     def get_metadata(self, record_id, type="xml"):
@@ -29,13 +32,16 @@ class InvenioV1Pipeline(base.BasePipeline):
 
         r = requests.get(record_url, params=payload)
 
-        logging.debug(f"Getting {r.url}")
+        log.debug(f"Getting {r.url}")
 
         if r.status_code != 200:
             raise Exception(f"Metadata request gave HTTP {r.status_code}.")
 
         self.metadata_url = r.url
-        self.metadata_size = r.headers["Content-length"]
+        try:
+            self.metadata_size = r.headers["Content-length"]
+        except Exception:
+            self.metadata_size = 0
         return r.content, r.url, r.status_code, "metadata.xml"
 
     def parse_metadata(self, metadata_filename):
@@ -51,10 +57,10 @@ class InvenioV1Pipeline(base.BasePipeline):
 
         # Parse the XML as MARC21
         #  and get the first record (result should be one record anyway)
-        logging.debug("Parsing metadata..")
+        log.debug("Parsing metadata..")
         try:
             record = marcxml.parse_xml_to_array(metadata_filename)[0]
-        except:
+        except Exception:
             raise Exception("Malformed metadata. Check if the record is public.")
         # Look for 856 entries
         #  MARC21: 856 - Electronic Location and Access (R)
@@ -72,7 +78,7 @@ class InvenioV1Pipeline(base.BasePipeline):
                 obj["url"] = f["d"]
                 obj["remote"] = "EOS"
             else:
-                logging.debug(f'Skipped 856 entry "{f}". No `u` or `d` field.')
+                log.debug(f'Skipped 856 entry "{f}". No `u` or `d` field.')
                 continue
 
             # File checksum
@@ -100,10 +106,8 @@ class InvenioV1Pipeline(base.BasePipeline):
             if obj["filename"]:
                 files.append(obj)
             else:
-                logging.warning(
-                    f'Skipped entry "{f}". No basename found (probably an URL?)'
-                )
-        logging.debug(f"Got {len(files)} files")
+                log.warning(f'Skipped entry "{f}". No basename found (probably an URL?)')
+        log.debug(f"Got {len(files)} files")
 
         meta_file_entry = {
             "filename": "metadata.xml",
@@ -121,32 +125,28 @@ class InvenioV1Pipeline(base.BasePipeline):
     def create_manifests(self, files, base_path):
         algs = ["md5", "sha1"]
         for alg in algs:
-            logging.info(f"Generating manifest {alg}..")
+            log.info(f"Generating manifest {alg}..")
             content = self.generate_manifest(files, alg, base_path)
             self.write_file(content, f"{base_path}/manifest-{alg}.txt")
 
     def download_files(self, files, files_base_path):
-        logging.info(f"Downloading {len(files)} files to {files_base_path}..")
+        log.info(f"Downloading {len(files)} files to {files_base_path}..")
         for sourcefile in files:
             if sourcefile["metadata"] == False:
                 destination = f'{files_base_path}/{sourcefile["filename"]}'
 
-                logging.debug(
+                log.debug(
                     f'Downloading {sourcefile["filename"]} from {sourcefile["url"]}..'
                 )
 
                 if sourcefile["remote"] == "HTTP":
                     sourcefile["downloaded"] = cds.downloadRemoteFile(
-                        sourcefile["url"],
-                        destination,
+                        sourcefile["url"], destination
                     )
                 elif sourcefile["remote"] == "EOS":
-                    cds.downloadEOSfile(
-                        sourcefile["url"],
-                        destination,
-                    )
+                    cds.downloadEOSfile(sourcefile["url"], destination)
             else:
-                logging.debug(
-                    f'Skipped downloading of {sourcefile["filename"]} from \
-                    {sourcefile["url"]}..'
+                log.debug(
+                    f'Skipped downloading of {sourcefile["filename"]} from              '
+                    f'       {sourcefile["url"]}..'
                 )
